open

Function open 

pub fn open(
    kweb_root: &Path,
    config: Config,
    identity_database: &Path,
) -> Result<(KwebManager, SystemRoots)>
Opens Kweb, bootstraps or validates both system roots, and transfers the sole database handle into Kweb Manager.